===============================
Django Cohort Analysis
===============================

.. image:: https://img.shields.io/travis/jturner/django_cohort_analysis.svg
        :target: https://travis-ci.org/jturner/django_cohort_analysis

.. image:: https://img.shields.io/pypi/v/django_cohort_analysis.svg
        :target: https://pypi.python.org/pypi/django_cohort_analysis


A small app to perform cohort analysis in Django

* Free software: BSD license
* Documentation: https://django_cohort_analysis.readthedocs.org.

Features
--------

* Perform cohort analysis on any django model that has a date_created or date_joined field

Credits
-------
This project was inspired by Alex Kehayia's django_cohorts_

.. _django_cohorts: http://alexkehayias.tumblr.com/post/18608787713/cohort-analysis-django

Work on this project was original undertaken at SpringMoves_.

.. _SpringMoves: http://www.springmoves.com
